@@ -6,7 +6,7 @@ from pydantic import BaseModel, Extra, Field, validator
 
 
 class Config(BaseModel, extra=Extra.ignore):
-    ai_draw_api: str = "http://91.217.139.190:5010"
+    ai_draw_api: str = "https://lulu.uedbq.xyz"
     ai_draw_token: str = ""
     ai_draw_cooldown: int = 60
     ai_draw_daily: int = 30
